require "faraday"
require "faraday_middleware"
require "hashie"

module Ticketlocker
  class Client
    attr_reader :conn

    def initialize(args)
      @token    = args[:token]
      @base_url = args.fetch(:base_url, 'http://ticketocker.io/api')
      @conn = Faraday.new(url: base_url) do |faraday|
        faraday.request  :json

        faraday.response :mashify
        faraday.response :json
        faraday.response :logger

        faraday.token_auth @token
        faraday.headers['User-Agent'] = "ticketlocker-ruby/#{Ticketlocker::VERSION}"

        faraday.adapter Faraday.default_adapter
      end

      if valid?
        return
      else
        raise Ticketlocker::Ruby::BadTokenError
      end
    end

    def validate
      response = conn.get('/api/validate')
      response.success?
    end

    alias :valid? :validate

    private
    attr_reader :token, :base_url
  end

  class Error < StandardError; end
  class BadTokenError < Error; end
end

